% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scraping.R
\name{search_tweets}
\alias{search_tweets}
\title{Buscar Tweets}
\usage{
search_tweets(query, n = 100, progress = TRUE, product = c("Latest", "Top"))
}
\arguments{
\item{query}{Consulta de busqueda (ej: "rstats", "#datascience", "from:usuario")}

\item{n}{Numero maximo de tweets a retornar (default: 100)}

\item{progress}{Mostrar barra de progreso (default: TRUE)}

\item{product}{Tipo de busqueda: "Latest" para tweets recientes o "Top" para tweets destacados (default: "Latest")}
}
\value{
Lista de tweets
}
\description{
Busca tweets usando una consulta
}
\examples{
\donttest{
if (check_setup()) {
  tweets <- search_tweets("rstats", n = 50)
  top_tweets <- search_tweets("rstats", n = 50, product = "Top")
  df <- to_dataframe(tweets)
}
}
}
