% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/accounts.R
\name{list_accounts}
\alias{list_accounts}
\title{Listar Cuentas}
\usage{
list_accounts(db_file = "accounts.db", verbose = TRUE)
}
\arguments{
\item{db_file}{Archivo de base de datos (default: "accounts.db")}

\item{verbose}{Si `TRUE`, emite mensajes informativos con `message()`/`warning()`; puede silenciarse con `suppressMessages()`/`suppressWarnings()`.}
}
\value{
Invisibly returns a list of configured accounts. Each account contains `username`, `email`, `active`, and `locks`; an empty list indicates no accounts or an error.
}
\description{
Lista todas las cuentas configuradas
}
\examples{
\donttest{
if (check_setup()) {
  accounts <- list_accounts()
  print(accounts)
}
}
}
