% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/setup.R
\name{check_setup}
\alias{check_setup}
\title{Verificar si twscrapeR esta configurado}
\usage{
check_setup(...)
}
\arguments{
\item{...}{Ignorado; reservado para compatibilidad futura.}
}
\value{
`TRUE` si twscrapeR esta configurado en la sesion actual; `FALSE` en caso contrario.
}
\description{
Verifica si Python y twscrape estan configurados en la sesion actual.
}
\examples{
check_setup()
}
