% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scraping.R
\name{search_hashtag}
\alias{search_hashtag}
\title{Buscar por Hashtag}
\usage{
search_hashtag(hashtag, n = 100, progress = TRUE)
}
\arguments{
\item{hashtag}{Hashtag (con o sin #)}

\item{n}{Numero maximo de tweets (default: 100)}

\item{progress}{Mostrar progreso (default: TRUE)}
}
\value{
Lista de tweets
}
\description{
Busca tweets que contengan un hashtag especifico
}
\examples{
\donttest{
if (check_setup()) {
  tweets <- search_hashtag("rstats", n = 50)
  tweets <- search_hashtag("#datascience", n = 100)
}
}
}
