% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scraping_advanced.R
\name{user_tweets_and_replies}
\alias{user_tweets_and_replies}
\title{Obtener Tweets y Respuestas de un Usuario}
\usage{
user_tweets_and_replies(username, n = 100, progress = TRUE)
}
\arguments{
\item{username}{Nombre de usuario (sin @)}

\item{n}{Numero maximo de tweets (default: 100)}

\item{progress}{Mostrar progreso (default: TRUE)}
}
\value{
Lista de tweets
}
\description{
Obtiene tweets y respuestas de un usuario (timeline completo)
}
\examples{
\donttest{
if (check_setup()) {
  all_tweets <- user_tweets_and_replies("elonmusk", n = 100)
}
}
}
