% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{print.twscraper_tweet}
\alias{print.twscraper_tweet}
\title{Metodo Print para Tweet Individual}
\usage{
\method{print}{twscraper_tweet}(x, ...)
}
\arguments{
\item{x}{Informacion de un tweet}

\item{...}{Argumentos adicionales}
}
\value{
Invisibly returns `x`, a `twscraper_tweet` list with tweet metadata, author fields, engagement counts, language, and URL.
}
\description{
Imprime informacion de un tweet individual
}
