% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scraping_advanced.R
\name{users_to_dataframe}
\alias{users_to_dataframe}
\title{Convertir Usuarios a Dataframe (alias de to_dataframe)}
\usage{
users_to_dataframe(users)
}
\arguments{
\item{users}{Lista de usuarios}
}
\value{
data.frame con informacion de usuarios
}
\description{
Alias interno de to_dataframe() - usar to_dataframe() directamente
}
\keyword{internal}
