% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scraping_advanced.R
\name{get_retweeters}
\alias{get_retweeters}
\title{Obtener Usuarios que Retuitearon}
\usage{
get_retweeters(tweet_id, n = 100, progress = TRUE)
}
\arguments{
\item{tweet_id}{ID del tweet}

\item{n}{Numero maximo de usuarios (default: 100)}

\item{progress}{Mostrar progreso (default: TRUE)}
}
\value{
Lista de usuarios
}
\description{
Obtiene la lista de usuarios que retuitearon un tweet especifico
}
\examples{
\donttest{
if (check_setup()) {
  retweeters <- get_retweeters(1234567890, n = 100)
}
}
}
