% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{print.twscraper_user}
\alias{print.twscraper_user}
\title{Metodo Print para Usuario}
\usage{
\method{print}{twscraper_user}(x, ...)
}
\arguments{
\item{x}{Informacion de usuario}

\item{...}{Argumentos adicionales}
}
\value{
Invisibly returns `x`, a `twscraper_user` list with fields such as `id`, `username`, `displayname`, `description`, follower/following counts, verification status, location, URL, and profile image URL.
}
\description{
Imprime informacion de usuario
}
