% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scraping_advanced.R
\name{get_retweeters_batch}
\alias{get_retweeters_batch}
\title{Obtener Retweeters para Varios Tweets}
\usage{
get_retweeters_batch(tweets, n = 100, progress = TRUE, flatten = TRUE)
}
\arguments{
\item{tweets}{Vector de IDs, lista de tweets `twscraper_tweets`, tweet individual o data.frame con columna `id`/`tweet_id`.}

\item{n}{Numero maximo de usuarios por tweet (default: 100)}

\item{progress}{Mostrar progreso (default: TRUE)}

\item{flatten}{Si es TRUE, devuelve una lista plana de usuarios con columna `source_tweet_id` para usar con `to_dataframe()`. Si es FALSE, devuelve una lista agrupada por tweet.}
}
\value{
Lista de usuarios con `source_tweet_id` o lista agrupada por tweet
}
\description{
Obtiene usuarios que retuitearon varios tweets en una sola llamada de R.
}
\examples{
\donttest{
if (check_setup()) {
  tweets <- search_tweets("rstats", n = 10)
  retweeters <- get_retweeters_batch(tweets, n = 50)
  retweeters_df <- to_dataframe(retweeters)

  retweeters_by_tweet <- get_retweeters_batch(tweets, n = 50, flatten = FALSE)
}
}
}
