% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{save_csv}
\alias{save_csv}
\title{Guardar Tweets como CSV}
\usage{
save_csv(tweets, file)
}
\arguments{
\item{tweets}{Lista de tweets}

\item{file}{Nombre del archivo}
}
\value{
Invisibly returns the output file path. The CSV contains one row per tweet/user-like item after conversion with `to_dataframe()`.
}
\description{
Guarda tweets en formato CSV
}
\examples{
\donttest{
tweets <- list(list(id = "1", text = "Hello R", username = "rstats"))
save_csv(tweets, tempfile(fileext = ".csv"))
}
}
