% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{print.twscraper_users}
\alias{print.twscraper_users}
\title{Metodo Print para Lista de Usuarios}
\usage{
\method{print}{twscraper_users}(x, ...)
}
\arguments{
\item{x}{Lista de usuarios}

\item{...}{Argumentos adicionales}
}
\value{
Invisibly returns `x`, a `twscraper_users` list. Each element represents one user with profile metadata and account statistics.
}
\description{
Imprime resumen de usuarios
}
