% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/accounts.R
\name{delete_account}
\alias{delete_account}
\title{Eliminar Cuenta}
\usage{
delete_account(username, db_file = "accounts.db", verbose = TRUE)
}
\arguments{
\item{username}{Nombre de usuario a eliminar}

\item{db_file}{Archivo de base de datos (default: "accounts.db")}

\item{verbose}{Si `TRUE`, emite mensajes informativos con `message()`/`warning()`; puede silenciarse con `suppressMessages()`/`suppressWarnings()`.}
}
\value{
Invisibly returns `TRUE` if the account was deleted; invisibly returns `FALSE` otherwise.
}
\description{
Elimina una cuenta de la base de datos
}
\examples{
\donttest{
if (check_setup() && interactive()) {
  # delete_account("your_username")
}
}
}
