% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scraping.R
\name{search_mentions}
\alias{search_mentions}
\title{Buscar Menciones de un Usuario}
\usage{
search_mentions(username, n = 100, progress = TRUE)
}
\arguments{
\item{username}{Nombre de usuario (sin @)}

\item{n}{Numero maximo de tweets (default: 100)}

\item{progress}{Mostrar progreso (default: TRUE)}
}
\value{
Lista de tweets
}
\description{
Busca tweets que mencionen a un usuario especifico
}
\examples{
\donttest{
if (check_setup()) {
  mentions <- search_mentions("hadleywickham", n = 50)
}
}
}
