% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{filter_by_date}
\alias{filter_by_date}
\title{Filtrar Tweets por Fecha}
\usage{
filter_by_date(tweets, from = NULL, to = NULL)
}
\arguments{
\item{tweets}{Lista de tweets}

\item{from}{Fecha inicial (POSIXct o character)}

\item{to}{Fecha final (POSIXct o character)}
}
\value{
Lista filtrada de tweets
}
\description{
Filtra tweets por rango de fechas
}
\examples{
\donttest{
tweets <- list(
  list(id = "1", date = as.POSIXct("2026-01-01")),
  list(id = "2", date = as.POSIXct("2026-02-01"))
)
class(tweets) <- c("twscraper_tweets", "list")
tweets_recent <- filter_by_date(tweets, from = "2025-10-01")
}
}
