% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{save_json}
\alias{save_json}
\title{Guardar Tweets como JSON}
\usage{
save_json(tweets, file)
}
\arguments{
\item{tweets}{Lista de tweets}

\item{file}{Nombre del archivo}
}
\value{
Invisibly returns the output file path. The JSON file contains the list structure supplied in `tweets`, written with `jsonlite::write_json()`.
}
\description{
Guarda tweets en formato JSON
}
\examples{
\donttest{
tweets <- list(list(id = "1", text = "Hello R", username = "rstats"))
save_json(tweets, tempfile(fileext = ".json"))
}
}
