% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/setup.R
\name{ensure_configured}
\alias{ensure_configured}
\title{Asegurar que twscrapeR esta configurado}
\usage{
ensure_configured()
}
\description{
Uso interno - verifica configuracion antes de operaciones
}
\keyword{internal}
