% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{filter_by_lang}
\alias{filter_by_lang}
\title{Filtrar Tweets por Idioma}
\usage{
filter_by_lang(tweets, lang)
}
\arguments{
\item{tweets}{Lista de tweets}

\item{lang}{Codigo de idioma (ej: "es", "en", "pt")}
}
\value{
Lista filtrada de tweets
}
\description{
Filtra tweets por idioma
}
\examples{
\donttest{
tweets <- list(
  list(id = "1", lang = "es"),
  list(id = "2", lang = "en")
)
class(tweets) <- c("twscraper_tweets", "list")
tweets_es <- filter_by_lang(tweets, "es")
}
}
