% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{print.twscraper_tweets}
\alias{print.twscraper_tweets}
\title{Metodo Print para Tweets}
\usage{
\method{print}{twscraper_tweets}(x, ...)
}
\arguments{
\item{x}{Lista de tweets}

\item{...}{Argumentos adicionales}
}
\value{
Invisibly returns `x`, a `twscraper_tweets` list. Each element represents one tweet with fields such as `id`, `date`, `text`, `username`, engagement counts, language, and URL.
}
\description{
Imprime resumen de tweets
}
