% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scraping_advanced.R
\name{tweet_replies}
\alias{tweet_replies}
\title{Obtener Respuestas a un Tweet}
\usage{
tweet_replies(tweet_id, n = 100, progress = TRUE)
}
\arguments{
\item{tweet_id}{ID del tweet}

\item{n}{Numero maximo de respuestas (default: 100)}

\item{progress}{Mostrar progreso (default: TRUE)}
}
\value{
Lista de tweets (respuestas)
}
\description{
Obtiene las respuestas (replies) a un tweet especifico
}
\examples{
\donttest{
if (check_setup()) {
  replies <- tweet_replies(1234567890, n = 50)
}
}
}
